api.reputation.v1 package — Argus-Toolbelt 1.0 documentation

# api.reputation.v1 package

## Subpackages

- api.reputation.v1.calculated package
  - Submodules
  - api.reputation.v1.calculated.calculated_domain module
  - Module contents
- api.reputation.v1.override package
  - Submodules
  - api.reputation.v1.override.override_domain module
  - Module contents

## Submodules

## api.reputation.v1.observation module

Autogenerated API

`api.reputation.v1.observation.` `add_observations`(sourceID: int = None, sourceAlias: str = None, observations: list = None, addAddresses: bool = 'True', addDomains: bool = 'True', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add reputation observations (INTERNAL)

  Return type: | `dict`
  Parameters: | sourceID (int) – sourceAlias (str) – observations (list) – Observations addAddresses (bool) – Whether add addresses (default true) addDomains (bool) – Whether add domains (default true)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“newCount”: 253, “continueCount”: 247, “awakenCount”: 667, “rejectedObservations”: [{“roleAlias”: “House young pattern shoulder company whole.”, “firstSeen”: 915, “lastSeen”: 692, “observationCount”: 140, “comment”: “Authority budget else leave try wait.”, “rejectReasons”: [“Role paper assume at let.”]}], “whitelistedObservations”: [{“roleAlias”: “Kid small last offer.”, “firstSeen”: 116, “lastSeen”: 752, “observationCount”: 235, “comment”: “Analysis life house drive.”, “rejectReasons”: [“Again design argue color third the perhaps notice.”]}]}

`api.reputation.v1.observation.` `delete_observations`(sourceAlias: str = None, address: list = None, fqdn: list = None, sourceID: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete reputation observations (INTERNAL)

  Return type: | `dict`
  Parameters: | sourceAlias (str) – Source alias address (list) – IP Addresses fqdn (list) – Domain names sourceID (int) – Source ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 585, “limit”: 206, “responseCode”: 200, “count”: 643, “data”: [{“id”: 239, “lastModified”: 862, “sourceId”: 336, “roleId”: 331, “firstSeen”: 530, “lastSeen”: 880, “numObservations”: 304, “state”: 582, “comment”: “Fast seem movie process foot oil about attorney.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Trip foreign civil late increase figure mother.”, “messageTemplate”: “Record figure your state growth technology.”, “field”: “Because blood land for field.”, “parameter”: {}, “timestamp”: 981263261}], “currentPage”: 434, “size”: 939}

`api.reputation.v1.observation.` `fetch_observations_for_domain`(fqdn: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Look up reputation observations for the given domain (INTERNAL)

  Return type: | `dict`
  Parameters: | fqdn (str) – Domain to fetch observations for
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 879, “limit”: 367, “responseCode”: 200, “count”: 897, “data”: [{“id”: 303, “lastModified”: 485, “sourceId”: 755, “roleId”: 615, “firstSeen”: 884, “lastSeen”: 287, “numObservations”: 392, “state”: 721, “comment”: “Black worker physical nothing art buy.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Gun require likely remain tonight.”, “messageTemplate”: “Visit reveal throughout lot need career.”, “field”: “Quickly play student field on senior beyond.”, “parameter”: {}, “timestamp”: 1336478303}], “currentPage”: 596, “size”: 900}

`api.reputation.v1.observation.` `fetch_observations_for_i_p`(ip: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Look up reputation observations for the given IP (INTERNAL)

  Return type: | `dict`
  Parameters: | ip (str) – IP address to fetch observations for
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 399, “limit”: 227, “responseCode”: 200, “count”: 166, “data”: [{“id”: 767, “lastModified”: 36, “sourceId”: 455, “roleId”: 489, “firstSeen”: 429, “lastSeen”: 407, “numObservations”: 105, “state”: 981, “comment”: “Remain information forward.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Democrat man author fast must pick choice realize.”, “messageTemplate”: “Cause end turn sense government table important.”, “field”: “Cost everything send usually middle social drug involve.”, “parameter”: {}, “timestamp”: 550317777}], “currentPage”: 655, “size”: 484}

`api.reputation.v1.observation.` `find_address_observations`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, minimumState: int = None, minimumConfidence: int = None, sourceID: list = None, startTimestamp: int = None, endTimestamp: int = None, fromAddress: str = None, afterAddress: str = None, addresses: list = None, sortBy: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List IP observations (INTERNAL)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – minimumState (int) – minimumConfidence (int) – sourceID (list) – startTimestamp (int) – endTimestamp (int) – fromAddress (str) – afterAddress (str) – addresses (list) – List of IP addresses sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 135, “limit”: 335, “responseCode”: 200, “count”: 41, “data”: [{“id”: 600, “lastModified”: 36, “sourceId”: 34, “roleId”: 878, “firstSeen”: 587, “lastSeen”: 797, “numObservations”: 23, “state”: 615, “comment”: “Run way lead commercial central try large.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Apply would sort occur marriage.”, “messageTemplate”: “Mean add dog.”, “field”: “News try build physical study decision.”, “parameter”: {}, “timestamp”: 416355942}], “currentPage”: 313, “size”: 368}

`api.reputation.v1.observation.` `find_domain_observations`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, minimumState: int = None, minimumConfidence: int = None, sourceID: list = None, startTimestamp: int = None, endTimestamp: int = None, fromDomainName: str = None, afterDomainName: str = None, domainNames: list = None, sortBy: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List domain observations (INTERNAL)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – minimumState (int) – minimumConfidence (int) – sourceID (list) – startTimestamp (int) – endTimestamp (int) – fromDomainName (str) – afterDomainName (str) – domainNames (list) – List of Full Qualified Domain Names sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 895, “limit”: 512, “responseCode”: 200, “count”: 852, “data”: [{“id”: 772, “lastModified”: 685, “sourceId”: 832, “roleId”: 206, “firstSeen”: 512, “lastSeen”: 302, “numObservations”: 297, “state”: 590, “comment”: “Sure beat bar near size policy kind happen.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Central station drop instead wife need for.”, “messageTemplate”: “Before face operation win at require little whatever.”, “field”: “Hold simple official find.”, “parameter”: {}, “timestamp”: 131223832}], “currentPage”: 548, “size”: 641}

`api.reputation.v1.observation.` `list_address_observations`(sourceID: int = None, minimumState: int = None, minimumConfidence: int = None, limit: int = 25, offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List IP observations (INTERNAL)

  Return type: | `dict`
  Parameters: | sourceID (int) – Limit result to observations from specified source minimumState (int) – Limit result to observations with this state or higher minimumConfidence (int) – Limit result to observations bound to sources with at least this confidence limit (int) – Limit result offset (int) – Offset result
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 241, “limit”: 320, “responseCode”: 200, “count”: 62, “data”: [{“id”: 147, “lastModified”: 402, “sourceId”: 417, “roleId”: 125, “firstSeen”: 459, “lastSeen”: 593, “numObservations”: 586, “state”: 584, “comment”: “Hospital everything member total buy.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “The center soldier southern car.”, “messageTemplate”: “Campaign measure modern hospital building second.”, “field”: “Democrat data body.”, “parameter”: {}, “timestamp”: 438939696}], “currentPage”: 886, “size”: 873}

`api.reputation.v1.observation.` `list_domain_observations`(sourceID: int = None, minimumState: int = None, minimumConfidence: int = None, limit: int = 25, offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List domain observations (INTERNAL)

  Return type: | `dict`
  Parameters: | sourceID (int) – Limit result to observations from specified source minimumState (int) – Limit result to observations with this state or higher minimumConfidence (int) – Limit result to observations bound to sources with at least this confidence limit (int) – Limit result offset (int) – Offset result
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 76, “limit”: 278, “responseCode”: 200, “count”: 718, “data”: [{“id”: 79, “lastModified”: 845, “sourceId”: 670, “roleId”: 651, “firstSeen”: 898, “lastSeen”: 90, “numObservations”: 452, “state”: 121, “comment”: “Mean floor almost station central tend.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Include line man remain.”, “messageTemplate”: “Yourself enough large young decade fill short.”, “field”: “Increase paper money me.”, “parameter”: {}, “timestamp”: 1278498021}], “currentPage”: 558, “size”: 574}

## api.reputation.v1.role module

Autogenerated API

`api.reputation.v1.role.` `add_new_role`(alias: str = None, name: str = None, score: int = 0.0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add new reputation role (INTERNAL)

  Return type: | `dict`
  Parameters: | alias (str) – Role alias => [a-zA-Z0-9_-.]* name (str) – Role name => [a-zA-Z0-9_-.]* score (int) – Role score (default 0.0)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 855, “limit”: 479, “responseCode”: 200, “count”: 591, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Program discuss generation great.”, “messageTemplate”: “Building pattern either feeling firm value eight.”, “field”: “Affect although stand voice high population agree.”, “parameter”: {}, “timestamp”: 402906782}], “currentPage”: 176, “size”: 44}

`api.reputation.v1.role.` `delete_role`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete reputation role (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of role to delete
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 138, “limit”: 805, “responseCode”: 200, “count”: 439, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Probably visit somebody require catch focus agreement security.”, “messageTemplate”: “True hit notice see couple floor forward.”, “field”: “Why indicate that word.”, “parameter”: {}, “timestamp”: 627878962}], “currentPage”: 361, “size”: 664}

`api.reputation.v1.role.` `get_role_by_alias`(alias: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch reputation role by role alias (INTERNAL)

  Return type: | `dict`
  Parameters: | alias (str) – Alias of role to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 802, “limit”: 996, “responseCode”: 200, “count”: 9, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Media although character hair then thousand thus.”, “messageTemplate”: “Difficult development care course page food kid.”, “field”: “Analysis medical tough media science natural.”, “parameter”: {}, “timestamp”: 554660976}], “currentPage”: 55, “size”: 16}

`api.reputation.v1.role.` `get_role_by_id`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch reputation role by ID (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of role to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 925, “limit”: 152, “responseCode”: 200, “count”: 532, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Kitchen listen window read.”, “messageTemplate”: “Newspaper admit discussion authority poor campaign body.”, “field”: “Baby toward poor word season.”, “parameter”: {}, “timestamp”: 1163088136}], “currentPage”: 744, “size”: 665}

`api.reputation.v1.role.` `list_roles`(search: str = None, offset: int = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List reputation roles (INTERNAL)

  Return type: | `dict`
  Parameters: | search (str) – Limit result to roles matching this search string offset (int) – Offset result limit (int) – Limit result
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 153, “limit”: 253, “responseCode”: 200, “count”: 671, “data”: [{“id”: 322, “flags”: 31, “alias”: “Eight eight notice plan.”, “name”: “Stephen Valenzuela”, “score”: 935, “deleted”: true, “lastUpdatedTimestamp”: 316670984}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Six audience dream.”, “messageTemplate”: “Rule door necessary family.”, “field”: “Western behind sometimes eight least.”, “parameter”: {}, “timestamp”: 1342096459}], “currentPage”: 889, “size”: 120}

`api.reputation.v1.role.` `search_roles`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, id: list = None, searchString: str = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search reputation roles (INTERNAL)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – id (list) – searchString (str) – includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 62, “limit”: 337, “responseCode”: 200, “count”: 791, “data”: [{“id”: 973, “flags”: 721, “alias”: “Employee pressure drive style trouble.”, “name”: “Paul King”, “score”: 990, “deleted”: true, “lastUpdatedTimestamp”: 1009610463}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Serious hotel memory response movement less skin.”, “messageTemplate”: “Tough store father their which health loss ten.”, “field”: “Final pretty give fall which apply.”, “parameter”: {}, “timestamp”: 1372056921}], “currentPage”: 968, “size”: 796}

`api.reputation.v1.role.` `update_role`(id: int, alias: str = None, name: str = None, score: int = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update reputation role (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of role to update alias (str) – [a-zA-Z0-9_-.]* name (str) – [a-zA-Z0-9_-.]* score (int) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 787, “limit”: 702, “responseCode”: 200, “count”: 324, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Offer call right reveal.”, “messageTemplate”: “Must during keep camera.”, “field”: “Go name second discuss hot remain road those.”, “parameter”: {}, “timestamp”: 1309455936}], “currentPage”: 642, “size”: 613}

## api.reputation.v1.source module

Autogenerated API

`api.reputation.v1.source.` `add_new_source`(alias: str = None, name: str = None, confidence: int = 0.0, activePeriod: int = 0, fudgePeriod: int = 0, useForReputationCalc: bool = 'False', monitored: bool = 'False', private: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add reputation source (INTERNAL)

  Return type: | `dict`
  Parameters: | alias (str) – Source alias => [a-zA-Z0-9_-.]* name (str) – Source name => [a-zA-Z0-9_-.]* confidence (int) – Source confidence (default 0.0) activePeriod (int) – Source active period (default 0) fudgePeriod (int) – Source fudge period (default 0) useForReputationCalc (bool) – monitored (bool) – private (bool) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 700, “limit”: 627, “responseCode”: 200, “count”: 879, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Edge themselves yeah night sing game.”, “messageTemplate”: “Democratic director wide form deal half finish.”, “field”: “Around Democrat head.”, “parameter”: {}, “timestamp”: 50670735}], “currentPage”: 434, “size”: 327}

`api.reputation.v1.source.` `delete_source`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete reputation source (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of source to delete
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 48, “limit”: 630, “responseCode”: 200, “count”: 375, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Financial admit act spring thus.”, “messageTemplate”: “Hotel policy remain shake name hope.”, “field”: “Safe avoid water sometimes one process play.”, “parameter”: {}, “timestamp”: 559320347}], “currentPage”: 467, “size”: 510}

`api.reputation.v1.source.` `find_sources`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, id: list = None, searchString: str = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search reputation sources (INTERNAL)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – id (list) – searchString (str) – includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 26, “limit”: 525, “responseCode”: 200, “count”: 516, “data”: [{“id”: 39, “alias”: “Conference teach probably wear.”, “name”: “Devin Fisher”, “confidence”: 75, “activePeriod”: 593, “fudgePeriod”: 282, “lastUpdatedTimestamp”: 377672571, “deleted”: false, “monitored”: false, “lastTransitionTimestamp”: 308104099, “useForReputationCalc”: false, “private”: true}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Theory admit surface but card wonder deal.”, “messageTemplate”: “Less technology do say vote whether.”, “field”: “Early lose democratic audience.”, “parameter”: {}, “timestamp”: 1462078312}], “currentPage”: 459, “size”: 211}

`api.reputation.v1.source.` `get_source_by_alias`(alias: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch reputation source by alias (INTERNAL)

  Return type: | `dict`
  Parameters: | alias (str) – Alias of source to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 791, “limit”: 970, “responseCode”: 200, “count”: 481, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Everyone part meet begin.”, “messageTemplate”: “Have with wrong attorney wrong music card.”, “field”: “Prepare can ok response.”, “parameter”: {}, “timestamp”: 1179009589}], “currentPage”: 875, “size”: 553}

`api.reputation.v1.source.` `get_source_by_id`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch reputation source by ID (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of source to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 835, “limit”: 997, “responseCode”: 200, “count”: 184, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Success if consider.”, “messageTemplate”: “Trial event opportunity for opportunity.”, “field”: “Others pick even bag short rest energy ball.”, “parameter”: {}, “timestamp”: 210083674}], “currentPage”: 772, “size”: 580}

`api.reputation.v1.source.` `list_sources`(search: str = None, offset: int = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List reputation sources (INTERNAL)

  Return type: | `dict`
  Parameters: | search (str) – Limit result to sources matching this search string offset (int) – Offset result limit (int) – Limit result
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 666, “limit”: 5, “responseCode”: 200, “count”: 396, “data”: [{“id”: 415, “alias”: “Them set writer west specific national.”, “name”: “Kenneth Walker”, “confidence”: 192, “activePeriod”: 818, “fudgePeriod”: 750, “lastUpdatedTimestamp”: 841584259, “deleted”: false, “monitored”: false, “lastTransitionTimestamp”: 420599733, “useForReputationCalc”: false, “private”: false}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Again kid camera adult.”, “messageTemplate”: “Among run short eye thing size think.”, “field”: “Tell staff cell position fly bag trade.”, “parameter”: {}, “timestamp”: 83825896}], “currentPage”: 187, “size”: 426}

`api.reputation.v1.source.` `update_source`(id: int, alias: str = None, name: str = None, confidence: int = None, activePeriod: int = None, fudgePeriod: int = None, useForReputationCalc: bool = 'False', monitored: bool = 'False', private: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update reputation source (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of source to update alias (str) – [a-zA-Z0-9_-.]* name (str) – [a-zA-Z0-9_-.]* confidence (int) – activePeriod (int) – fudgePeriod (int) – useForReputationCalc (bool) – monitored (bool) – private (bool) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 70, “limit”: 823, “responseCode”: 200, “count”: 277, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Morning say look will.”, “messageTemplate”: “Choose floor ever natural PM stage.”, “field”: “In name garden big price prove.”, “parameter”: {}, “timestamp”: 629609045}], “currentPage”: 461, “size”: 766}

## Module contents